@@ -20,7 +20,7 @@
 
 
 #include	"glemisc.h"
-#include	"glemainwindow.h"
+#include	"glepublic.h"
 
 
 #ifdef __cplusplus
@@ -36,10 +36,6 @@ extern	const guint	gle_libversion_revision;
 extern	const guint	gle_libversion_age;
 extern	const gchar	*gle_libversion;
 
-void		gle_init	(int          *argc_p,
-				 char       ***argv_p);
-const gchar*	gle_prg_name	(void);
-
 
 
 
