@@ -35,15 +35,20 @@ void		gle_set_flash_widget		(GtkWidget	*widget);
 GtkWidget*	gle_get_flash_widget		(void);
 void		gle_widget_make_sensitive	(GtkWidget	*widget);
 void		gle_widget_make_insensitive	(GtkWidget	*widget);
-GtkWidget*	gle_class_show_signals		(GtkObjectClass	*klass,
-						 const gchar	*selected);
-GtkWidget*	gle_widget_show_flags		(GtkWidget	*widget);
 GtkType		gle_type_from_name		(const gchar	*arg_name,
 						 const gchar	**class_name_p);
 
 
 /* unimplemented gtk stuff
  */
+#define GTK_VALUE_WIDGET(a)     ((GtkWidget*)GTK_VALUE_OBJECT(a))
+typedef	void	(*GtkCListRowFunc)	(GtkCList	*clist,
+					 guint		 row,
+					 gpointer	*row_data_p,
+					 gpointer	 func_data);
+void	gtk_clist_row_foreach	(GtkCList		*clist,
+				 GtkCListRowFunc	func,
+				 gpointer		func_data);
 GList*		gtk_widget_query_arg_list	(GtkWidget *widget,
 						 GtkType    class_type);
 void		gtk_widget_queue_destroy	(GtkWidget	*widget);
