@@ -19,7 +19,7 @@
 #define __GLEPRIVATE_H__
 
 
-#include	"glemainwindow.h"
+#include	"glemisc.h"
 
 
 #ifdef __cplusplus
@@ -28,18 +28,28 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-/* --- GLE macros --- */
-#define GLE_IS_GLE_OBJECT(object)       (gle_object_has_gle_tag ((object)))
-#define GLE_GET_MAIN_WINDOW(object)     (gle_object_get_gle_tag ((object)))
+/* --- macros --- */
+/* macros that are used to tag gtkobjects as internal GLE objects.
+ * this mechanism is lekly to change...
+ */
+#define GLE_TAG(object)			G_STMT_START{if(!GLE_HAS_TAG(object)){gle_root_connect_object_life(GTK_OBJECT(object));GLE_WEAK_TAG(object);}}G_STMT_END
+#define GLE_WEAK_TAG(object)		G_STMT_START{gtk_object_set_data(GTK_OBJECT(object),gle_key_gle_tag,(gpointer)42);}G_STMT_END
+#define	GLE_HAS_TAG(object)		(gtk_object_get_data(GTK_OBJECT(object),gle_key_gle_tag)==(gpointer)42)
+
 
 /* --- keys --- */
-extern	const	gchar   *gle_key_main_window;
+extern const gchar	*gle_key_gle_tag;
+extern const gchar	*gle_key_shell;
 
 
 /* --- prototypes --- */
-void            gle_object_set_gle_tag          (GtkObject      *object);
-gboolean        gle_object_has_gle_tag          (GtkObject      *object);
-GleMainWindow*  gle_object_get_gle_tag          (GtkObject      *object);
+GtkObject*	gle_root_object			(void);
+void		gle_root_shutdown		(void);
+void		gle_root_connect_object_life	(GtkObject	*object);
+GtkWidget*	gle_root_get_shell		(void);
+
+gchar*          gle_object_create_glename       (GtkObject      *object);
+
      
 
 
